summaryrefslogtreecommitdiff
path: root/include/git2
diff options
context:
space:
mode:
authorEdward Thomson <ethomson@edwardthomson.com>2015-10-22 17:00:09 -0400
committerEdward Thomson <ethomson@microsoft.com>2015-11-25 15:37:05 -0500
commitfa78782f67d17c5b139a2bbe3ceefe54c8c71dd3 (patch)
tree53dbcd502af2400529a3f8db828612d90d12cf06 /include/git2
parentc4f60543b7ccfce852ebdc8c12b62c99a5d4c2a5 (diff)
downloadlibgit2-fa78782f67d17c5b139a2bbe3ceefe54c8c71dd3.tar.gz
merge: rename `git_merge_tree_flags_t` -> `git_merge_flags_t`
Diffstat (limited to 'include/git2')
-rw-r--r--include/git2/merge.h36
1 files changed, 19 insertions, 17 deletions
diff --git a/include/git2/merge.h b/include/git2/merge.h
index b7da63e0e..de224aeac 100644
--- a/include/git2/merge.h
+++ b/include/git2/merge.h
@@ -62,8 +62,8 @@ GIT_EXTERN(int) git_merge_file_init_input(
unsigned int version);
/**
- * Flags for `git_merge_tree` options. A combination of these flags can be
- * passed in via the `tree_flags` value in the `git_merge_options`.
+ * Flags for `git_merge` options. A combination of these flags can be
+ * passed in via the `flags` value in the `git_merge_options`.
*/
typedef enum {
/**
@@ -71,20 +71,20 @@ typedef enum {
* side or the common ancestor and the "theirs" side. This will enable
* the ability to merge between a modified and renamed file.
*/
- GIT_MERGE_TREE_FIND_RENAMES = (1 << 0),
+ GIT_MERGE_FIND_RENAMES = (1 << 0),
/**
- * If a conflict occurs, exit immediately instead of attempting to
- * continue resolving conflicts. The merge operation will fail with
- * GIT_EMERGECONFLICT and no index will be returned.
+ * Do not write the REUC extension on the generated index
*/
- GIT_MERGE_TREE_FAIL_ON_CONFLICT = (1 << 1),
+ GIT_MERGE_SKIP_REUC = (1 << 2),
/**
- * Do not write the REUC extension on the generated index
+ * If a conflict occurs, exit immediately instead of attempting to
+ * continue resolving conflicts. The merge operation will fail with
+ * GIT_EMERGECONFLICT and no index will be returned.
*/
- GIT_MERGE_TREE_SKIP_REUC = (1 << 2),
-} git_merge_tree_flag_t;
+ GIT_MERGE_FAIL_ON_CONFLICT = (1 << 1),
+} git_merge_flag_t;
/**
* Merge file favor options for `git_merge_options` instruct the file-level
@@ -152,7 +152,7 @@ typedef enum {
/** Take extra time to find minimal diff */
GIT_MERGE_FILE_DIFF_MINIMAL = (1 << 7),
-} git_merge_file_flags_t;
+} git_merge_file_flag_t;
/**
* Options for merging a file
@@ -181,8 +181,8 @@ typedef struct {
/** The file to favor in region conflicts. */
git_merge_file_favor_t favor;
- /** see `git_merge_file_flags_t` above */
- unsigned int flags;
+ /** see `git_merge_file_flag_t` above */
+ git_merge_file_flag_t flags;
} git_merge_file_options;
#define GIT_MERGE_FILE_OPTIONS_VERSION 1
@@ -232,11 +232,13 @@ typedef struct {
*/
typedef struct {
unsigned int version;
- git_merge_tree_flag_t tree_flags;
+
+ /** See `git_merge_flag_t` above */
+ git_merge_flag_t flags;
/**
* Similarity to consider a file renamed (default 50). If
* `GIT_MERGE_TREE_FIND_RENAMES` is enabled, added files will be compared
* with deleted files to determine their similarity. Files that are
* more similar than the rename threshold (percentage-wise) will be
* treated as a rename.
@@ -258,8 +260,8 @@ typedef struct {
/** Flags for handling conflicting content. */
git_merge_file_favor_t file_favor;
- /** see `git_merge_file_flags_t` above */
- unsigned int file_flags;
+ /** see `git_merge_file_flag_t` above */
+ git_merge_file_flag_t file_flags;
} git_merge_options;
#define GIT_MERGE_OPTIONS_VERSION 1
@@ -232,11 +232,13 @@ typedef struct {
/**
* Similarity to consider a file renamed (default 50). If
- * `GIT_MERGE_TREE_FIND_RENAMES` is enabled, added files will be compared
+ * `GIT_MERGE_FIND_RENAMES` is enabled, added files will be compared
* with deleted files to determine their similarity. Files that are
* more similar than the rename threshold (percentage-wise) will be